merkle_root

Function merkle_root 

pub fn merkle_root(
    leaves: Vec<Fp<MontBackend<FqConfig, 4>, 4>>,
) -> Fp<MontBackend<FqConfig, 4>, 4>
Build a Merkle root from a full list of leaves

Computes the Merkle root by repeatedly hashing pairs of nodes until a single root remains.

Panics

Panics if leaves is empty.