pub struct MerkleTree { /* private fields */ }Expand description
Simple Merkle tree for proof generation
Implementations
Sourceimpl MerkleTree
impl MerkleTree
Sourcepub fn new(depth: usize) -> Result<MerkleTree, JsValue>
pub fn new(depth: usize) -> Result<MerkleTree, JsValue>
Create a new Merkle tree with given depth and default zero leaf (0)
Sourcepub fn new_with_zero_leaf(
depth: usize,
zero_leaf_bytes: &[u8],
) -> Result<MerkleTree, JsValue>
pub fn new_with_zero_leaf( depth: usize, zero_leaf_bytes: &[u8], ) -> Result<MerkleTree, JsValue>
Create a new Merkle tree with a custom zero leaf value. This allows matching contract implementations that use non-zero empty leaves (e.g., poseidon2(“XLM”) as the zero value).
Arguments
depth- Tree depth (1-32)zero_leaf_bytes- Custom zero leaf value as 32 bytes (Little-Endian)
Sourcepub fn insert(&mut self, leaf_bytes: &[u8]) -> Result<u32, JsValue>
pub fn insert(&mut self, leaf_bytes: &[u8]) -> Result<u32, JsValue>
Insert a leaf and return its index
Sourcepub fn get_proof(&self, index: u32) -> Result<MerkleProof, JsValue>
pub fn get_proof(&self, index: u32) -> Result<MerkleProof, JsValue>
Get merkle proof for a leaf at given index
Sourcepub fn next_index(&self) -> u64
pub fn next_index(&self) -> u64
Get the next available leaf index